@@ -1,7 +1,5 @@
 """Tests for the utils of ``django_libs``."""
 from django.conf import settings
-from django.contrib.auth.decorators import login_required
-from django.utils.decorators import method_decorator
 from django.test import TestCase
 from django.contrib.auth.models import SiteProfileNotAvailable
 
